import { FunnelIcon, MagnifyingGlassIcon } from "@heroicons/react/24/outline";
import { leaders } from "./mock";
import { useMemo, useState } from "react";
import { Leader } from "./types";
import { Input, Select } from "antd";
import { motion } from "framer-motion";

const { Search } = Input;

interface FilterProps {
    onSearch?: (query: string) => void;
    onDivisionChange?: (division: string) => void;
}

export default function Filter({ onSearch, onDivisionChange }: FilterProps) {
    const [searchQuery, setSearchQuery] = useState('');
    const [selectedDivision, setSelectedDivision] = useState<string>('all');

    const divisions = useMemo(() => {
        return ['all', ...new Set(leaders.map(leader => leader.division))];
    }, []);

    const handleSearch = (value: string) => {
        setSearchQuery(value);
        onSearch?.(value);
    };

    const handleDivisionChange = (value: string) => {
        setSelectedDivision(value);
        onDivisionChange?.(value);
    };

    return (
        <motion.div
            className="flex flex-col md:flex-row gap-4 mb-8"
            initial={{ opacity: 0, y: 20 }}
            animate={{ opacity: 1, y: 0 }}
            transition={{ duration: 0.3 }}
        >
            <div className="flex-1">
                <Search
                    placeholder="Search by name or rank..."
                    allowClear
                    enterButton={
                        <div className="flex items-center gap-2">
                            <MagnifyingGlassIcon className="w-5 h-5" />
                            <span>Search</span>
                        </div>
                    }
                    size="large"
                    value={searchQuery}
                    onChange={(e) => handleSearch(e.target.value)}
                    className="rounded-lg"
                />
            </div>

            <Select
                size="large"
                value={selectedDivision}
                onChange={handleDivisionChange}
                suffixIcon={<FunnelIcon className="w-5 h-5 text-gray-400" />}
                className="w-full md:w-64"
                options={divisions.map(division => ({
                    value: division,
                    label: division === 'all' ? 'All Divisions' : division,
                }))}
            />
        </motion.div>
    );
}
